sigaction

Function sigaction 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn sigaction( sig: c_int, act: *const sigaction, oact: *mut sigaction, ) -> c_int
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/sigaction.html.

Allows the calling process to examine and/or specify the action to be associated with a specific signal.

Upon success, returns 0. Upon failure, returns -1, sets errno to indicate the error, and no new signal-catching function shall be installed.