#[unsafe(no_mangle)]pub unsafe extern "C" fn sigdelset(
set: *mut sigset_t,
signo: c_int,
) -> c_intExpand description
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/sigdelset.html.
Deletes the individual signal specified by signo to the signal set
pointed to by set.
Upon success, returns 0. Upon failure, returns -1 and sets errno to
indicate the error.
Safety
The sigset_t pointed to by set must be initialized by sigemptyset()
or sigfillset() before calling this function or undefined behaviour will
occur.