sighold

Function sighold 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn sighold(sig: c_int) -> c_int
👎Deprecated
See https://pubs.opengroup.org/onlinepubs/9699919799/functions/sighold.html.

Adds sig to the signal mask of the calling process.

Upon success, returns 0. Upon failure, returns -1 and sets errno to indicate the error.

Deprecated

Present in issue 7. Removed in issue 8.

Use of this function is unspecified in a multi-threaded process.

pthread_sigmask() or sigprocmask() should be used instead.

Implementation

Calls sigprocmask() internally.