sigismember

Function sigismember 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn sigismember( set: *const sigset_t, signo: c_int, ) -> c_int
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/sigismember.html.

Tests whether the signal specified by signo is a member of the set pointed to by set.

Upon success, return 1 if the specified signal is a member of the specified set, or 0 if it is not. Upon failure, returns -1 and sets errno to indicate the error.

Safety

The sigset_t pointed to by set must be initialized by sigemptyset() or sigfillset() before calling this function or undefined behaviour will occur.