#[unsafe(no_mangle)]pub unsafe extern "C" fn sigtimedwait(
set: *const sigset_t,
sig: *mut siginfo,
tp: *const timespec,
) -> c_intExpand description
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/sigtimedwait.html.
Equivalent to sigwaitinfo() except that if none of the signals specified
by set are pending, wait for the time interval specified in the
timespec structure referenced by timeout. Shall return immediately with
an error if timeout is zero-valued and none of the signals specified by
set are pending.
Upon success, returns the selected signal number. Upon failure, returns
-1 and sets errno to indicate the error.
Safety
If timeout is the null pointer, behaviour is unspecified.