sigwait

Function sigwait 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn sigwait( set: *const sigset_t, sig: *mut c_int, ) -> c_int
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/sigwait.html.

Selects a pending signal from set, atomically clears it from the system’s set of pending signals, and return that signal number in the location referenced by sig.

Upon success, stores the signal number of the received signal at the location referenced by sig and returns 0. Upon failure, an error number is returned to indicate the error.