#[unsafe(no_mangle)]pub unsafe extern "C" fn pthread_kill(
thread: pthread_t,
sig: c_int,
) -> c_intExpand description
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/pthread_kill.html.
Requests that a signal be delivered to the specified thread. It shall not
be an error is thread is a zombie thread.
Upon success, returns 0. Upon failure, returns an error number and does
not send the signal.