#[unsafe(no_mangle)]pub extern "C" fn raise(sig: c_int) -> c_intExpand description
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/raise.html.
Sends the signal sig to the executing thread or process. If a signal
handler is called, this function shall not return until after the signal
handler does.
Upon success, returns 0. Upon failure, returns a non-zero value and sets
errno to indicate the error.