#[unsafe(no_mangle)]pub unsafe extern "C" fn sigaltstack(
ss: *const stack_t,
old_ss: *mut stack_t,
) -> c_intExpand description
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/sigaltstack.html.
Allows a process to define and examine the state of an alternate stack for signal handlers for the current thread.
Upon success, returns 0. Upon failure, returns -1 and sets errno to
indicate the error.
Safety
Use of this function by library threads that are not bound to kernel-scheduled entities results in undefined behaviour.