#[unsafe(no_mangle)]pub unsafe extern "C" fn sigpause(sig: c_int) -> c_int👎Deprecated
See https://pubs.opengroup.org/onlinepubs/9699919799/functions/sighold.html.
Removes sig from the signal mask of the calling process and suspend the
calling process until a signal is received.
Suspends execution of the thread until a signal is received, whereupon it
shall return -1 and set errno to EINTR.
Deprecated
Present in issue 7. Removed in issue 8.
Use of this function is unspecified in a multi-threaded process.
sigsuspend() should be used instead.
Implementation
Calls sigsuspend() internally.