#[unsafe(no_mangle)]pub unsafe extern "C" fn sigpending(set: *mut sigset_t) -> c_intExpand description
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/sigpending.html.
Stores, in the location referenced by the set argument, the set of
signals that are blocked from delivery to the calling thread and that are
pending on the process or the calling thread.
Upon success, returns 0. Upon failure, returns -1 and sets errno to
indicate the error.