#[unsafe(no_mangle)]pub unsafe extern "C" fn sigprocmask(
how: c_int,
set: *const sigset_t,
oset: *mut sigset_t,
) -> c_intExpand description
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/sigprocmask.html.
Examines or changes (or both) the calling thread’s signal mask.
Upon success, returns 0. Upon failure, returns -1, sets errno to
indicate the error, and does not change the signal mask.
Use of this function is unspecified in a multi-threaded process.