#[unsafe(no_mangle)]pub extern "C" fn sigqueue(
pid: pid_t,
signo: c_int,
value: sigval,
) -> c_intExpand description
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/sigqueue.html.
Causes the signal specified by signo to be sent with the value specified
by value to the process specified by pid.
Upon success, the specified signal shall have been queued, and returns 0.
Upon error, returns -1 and sets errno to indicate the error.