#[unsafe(no_mangle)]pub unsafe extern "C" fn sigset(
sig: c_int,
func: Option<extern "C" fn(c_int)>,
) -> Option<extern "C" fn(c_int)>👎Deprecated
See https://pubs.opengroup.org/onlinepubs/9699919799/functions/sighold.html.
Modifies signal dispositions.
Upon success, returns SIG_HOLD if the signal had been blocked and the
signal’s previous disposition if it had not been blocked. Upon failure,
returns SIG_ERR and sets errno to indicate the error.
Deprecated
Present in issue 7. Removed in issue 8.
Use of this function is unspecified in a multi-threaded process.
sigaction() should be used instead.
Implementation
Calls sigaction() internally.