#[unsafe(no_mangle)]pub unsafe extern "C" fn sigsuspend(sigmask: *const sigset_t) -> c_intExpand description
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/sigsuspend.html.
Atomically both replace the current signal mask of the calling thread with
the set of signals pointed to by sigmask and suspend the thread until
delivery of a signal whose action is either to execute a signal-catching
function or to terminate the process.
Upon success, suspends thread execution and does not return. If the action
is to execute a signal-catching function, returns -1 after the
signal-catching function returns, and restores the signal mask back to the
set that existed prior to calling this function, then sets errno to
indicate the error. Upon failure, returns -1 and sets errno to indicate
the error.