#[repr(C)]pub struct sigaction {
pub sa_handler: Option<extern "C" fn(c_int)>,
pub sa_flags: c_int,
pub sa_restorer: Option<unsafe extern "C" fn()>,
pub sa_mask: sigset_t,
}Expand description
cbindgen:ignore See https://pubs.opengroup.org/onlinepubs/9799919799/basedefs/signal.h.html.
Implementation
This struct in Rust is missing the sa_sigaction field. The stucture in
cbindgen uses a union to combine sa_handler and sa_sigaction. POSIX
states that both fields shall not be used simultaneously.
Fields
sa_handler: Option<extern "C" fn(c_int)>Pointer to a signal-catching function or one of the SIG_IGN or
SIG_DFL.
sa_flags: c_intSpecial flags.
sa_restorer: Option<unsafe extern "C" fn()>Non-POSIX, see https://www.man7.org/linux/man-pages/man2/sigaction.2.html.
Not intended for application use. A sigaction wrapper function is
intended to use this to store the location of the trampoline code and
setting the SA_RESTORER flag in sa_flags.
sa_mask: sigset_tSet of signals to be blocked during execution of the signal handling function.